@@ -13,30 +13,20 @@
 #include "tokodon_debug.h"
 #endif
 
+#include "messagefiltercontainer.h"
+#include "tokodon-version.h"
+
 #include <config.h>
 #include <qt6keychain/keychain.h>
 
 using namespace Qt::Literals::StringLiterals;
 
-Account::Account(const QString &instanceUri, QNetworkAccessManager *nam, bool ignoreSslErrors, bool admin, QObject *parent)
-    : AbstractAccount(parent, instanceUri)
-    , m_ignoreSslErrors(ignoreSslErrors)
+Account::Account(const QString &instanceUri, QNetworkAccessManager *nam, QObject *parent)
+    : AbstractAccount(instanceUri, parent)
     , m_qnam(nam)
 {
-    m_preferences = new Preferences(this);
-    setInstanceUri(instanceUri);
-    m_requestingAdmin = admin;
-}
-
-Account::Account(AccountConfig *settings, QNetworkAccessManager *nam, QObject *parent)
-    : AbstractAccount(parent)
-    , m_qnam(nam)
-{
-    m_preferences = new Preferences(this);
-    m_config = settings;
     connect(this, &Account::authenticated, this, &Account::checkForFollowRequests);
     connect(this, &Account::authenticated, this, &Account::checkForUnreadNotifications);
-    buildFromSettings();
 }
 
 Account::~Account()
@@ -44,6 +34,11 @@ Account::~Account()
     m_identityCache.clear();
 }
 
+bool Account::successfullyAuthenticated() const
+{
+    return m_authenticated;
+}
+
 void Account::get(const QUrl &url,
                   bool authenticated,
                   QObject *parent,
@@ -175,6 +170,8 @@ void Account::handleReply(QNetworkReply *reply, std::function<void(QNetworkReply
         reply->deleteLater();
         if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) && !reply->url().toString().contains("nodeinfo"_L1)) {
             if (errorCallback) {
+                // If the error is handled, then only emit it for people interested in debug logs
+                qCDebug(TOKODON_HTTP) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
                 errorCallback(reply);
             } else {
                 qCWarning(TOKODON_HTTP) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
@@ -186,11 +183,6 @@ void Account::handleReply(QNetworkReply *reply, std::function<void(QNetworkReply
             reply_cb(reply);
         }
     });
-    if (m_ignoreSslErrors) {
-        connect(reply, &QNetworkReply::sslErrors, this, [reply](const QList<QSslError> &) {
-            reply->ignoreSslErrors();
-        });
-    }
 }
 
 // assumes file is already opened and named
@@ -270,14 +262,19 @@ QWebSocket *Account::streamingSocket(const QString &stream)
             }
         }
     });
+    connect(socket, &QWebSocket::errorOccurred, this, [=](QAbstractSocket::SocketError) {
+        qCWarning(TOKODON_HTTP) << "Error in" << stream << ":" << socket->errorString();
+    });
 
-    socket->open(url);
+    QNetworkRequest request(url);
+    request.setHeader(QNetworkRequest::UserAgentHeader, QStringLiteral("Tokodon/").append(QStringLiteral(TOKODON_VERSION_STRING)));
+    socket->open(request);
 
     m_websockets[stream] = socket;
     return socket;
 }
 
-void Account::validateToken(bool newAccount)
+void Account::validateToken()
 {
     const QUrl verify_credentials = apiUrl(QStringLiteral("/api/v1/accounts/verify_credentials"));
 
@@ -304,18 +301,9 @@ void Account::validateToken(bool newAccount)
             m_identity = identityLookup(object["id"_L1].toString(), object);
             m_name = m_identity->username();
             Q_EMIT identityChanged();
+            m_authenticated = true;
             Q_EMIT authenticated(true, {});
 
-#ifdef HAVE_KUNIFIEDPUSH
-            if (newAccount) {
-                // We asked for the push scope, so we can safely start subscribing to notifications
-                config()->setEnablePushNotifications(true);
-                config()->save();
-            }
-#else
-            Q_UNUSED(newAccount)
-#endif
-
 #ifdef HAVE_KUNIFIEDPUSH
             get(
                 apiUrl(QStringLiteral("/api/v1/push/subscription")),
@@ -357,21 +345,18 @@ void Account::validateToken(bool newAccount)
     streamingSocket(QStringLiteral("user"));
 }
 
+void Account::setConfig(AccountConfig *config)
+{
+    m_config = config;
+    buildFromSettings();
+}
+
 void Account::writeToSettings()
 {
-    // do not write to settings if we do not have complete information yet,
-    // or else it writes malformed and possibly duplicate accounts to settings.
-    if (m_name.isEmpty() || m_instance_uri.isEmpty()) {
-        return;
-    }
-
-    AccountConfig config(settingsGroupName());
-    config.setClientId(m_client_id);
-    config.setInstanceUri(m_instance_uri);
-    config.setName(m_name);
-    config.setIgnoreSslErrors(m_ignoreSslErrors);
-
-    config.save();
+    config()->setClientId(m_client_id);
+    config()->setInstanceUri(m_instance_uri);
+    config()->setName(m_name);
+    config()->save();
 
     auto accessTokenJob = new QKeychain::WritePasswordJob{QStringLiteral("Tokodon"), this};
 #ifdef SAILFISHOS
@@ -392,10 +377,10 @@ void Account::writeToSettings()
 
 void Account::buildFromSettings()
 {
-    m_client_id = m_config->clientId();
-    m_name = m_config->name();
-    m_instance_uri = m_config->instanceUri();
-    m_ignoreSslErrors = m_config->ignoreSslErrors();
+    Q_ASSERT(config());
+
+    m_client_id = config()->clientId();
+    m_name = config()->name();
 
     auto accessTokenJob = new QKeychain::ReadPasswordJob{QStringLiteral("Tokodon"), this};
 #ifdef SAILFISHOS
@@ -403,10 +388,8 @@ void Account::buildFromSettings()
 #endif
     accessTokenJob->setKey(accessTokenKey());
 
-    QObject::connect(accessTokenJob, &QKeychain::ReadPasswordJob::finished, [this, accessTokenJob]() {
-        m_token = accessTokenJob->textData();
-
-        validateToken();
+    connect(accessTokenJob, &QKeychain::ReadPasswordJob::finished, [this, accessTokenJob]() {
+        setAccessToken(accessTokenJob->textData());
     });
 
     accessTokenJob->start();
@@ -417,7 +400,7 @@ void Account::buildFromSettings()
 #endif
     clientSecretJob->setKey(clientSecretKey());
 
-    QObject::connect(clientSecretJob, &QKeychain::ReadPasswordJob::finished, [this, clientSecretJob]() {
+    connect(clientSecretJob, &QKeychain::ReadPasswordJob::finished, [this, clientSecretJob]() {
         m_client_secret = clientSecretJob->textData();
     });
 
@@ -544,12 +527,12 @@ QUrlQuery Account::buildNotificationFormData()
     return formdata;
 }
 
-void Account::registerTokodon(const bool authCode)
+void Account::registerTokodon(const bool useAuthCode, const bool addAdminScope)
 {
     registerApplication(QStringLiteral("Tokodon"),
                         QStringLiteral("https://apps.kde.org/tokodon"),
-                        m_requestingAdmin ? QStringLiteral("admin:read admin:write") : QStringLiteral(""),
-                        authCode);
+                        addAdminScope ? QStringLiteral("admin:read admin:write") : QStringLiteral(""),
+                        useAuthCode);
 }
 
 #include "moc_account.cpp"
