@@ -27,15 +27,15 @@ public:
 
     explicit RulesModel(QObject *parent = nullptr);
 
-    bool loading() const;
+    [[nodiscard]] bool loading() const;
     void setLoading(bool loading);
 
-    AbstractAccount *account() const;
+    [[nodiscard]] AbstractAccount *account() const;
     void setAccount(AbstractAccount *account);
 
-    QVariant data(const QModelIndex &index, int role) const override;
-    int rowCount(const QModelIndex &parent) const override;
-    QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
 Q_SIGNALS:
     void loadingChanged();
@@ -51,5 +51,5 @@ private:
     QList<Rule> m_rules;
     bool m_loading = false;
     AbstractAccount *m_account = nullptr;
-    Rule fromSourceData(const QJsonObject &object) const;
+    [[nodiscard]] Rule fromSourceData(const QJsonObject &object) const;
 };
